@@ -67,7 +67,7 @@ async def event_wait(event: asyncio.Event, timeout=None):
     Wait on an an asyncio event with an optional timeout
 
     Returns:
-        true if the event got set, None if timed out
+        true if the event got set, False if timed out
     '''
     if timeout is None:
         await event.wait()
@@ -148,7 +148,7 @@ async def spawn(todo, timeout=None, ctx=None):
     Run a todo (func, args, kwargs) tuple in a multiprocessing subprocess.
 
     Args:
-        todo (tuple): A tuple of function, *args, and **kwargs.
+        todo (tuple): A tuple of function, ``*args``, and ``**kwargs``.
         timeout (int): The timeout to wait for the todo function to finish.
         ctx (multiprocess.Context): A optional multiprocessing context object.
 
