@@ -269,6 +269,12 @@ class WebSocket(HandlerBase, t_websocket.WebSocketHandler):
 
 class Handler(HandlerBase, t_web.RequestHandler):
 
+    def prepare(self):
+        self.task = asyncio.current_task()
+
+    def on_connection_close(self):
+        self.task.cancel()
+
     async def _reqValidOpts(self, opts):
 
         if opts is None:
@@ -399,7 +405,7 @@ class WatchSockV1(WebSocket):
             text = e.get('mesg', str(e))
             await self.xmit('errx', code=e.__class__.__name__, mesg=text)
 
-        except asyncio.CancelledError:
+        except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
             raise
 
         except Exception as e:
