@@ -77,6 +77,7 @@ class Snap(s_base.Base):
         # Keeps alive the most recently accessed node objects
         self.buidcache = collections.deque(maxlen=self._buidcachesize)
         self.livenodes = weakref.WeakValueDictionary()  # buid -> Node
+        self._warnonce_keys = set()
 
         self.onfini(self.stack.close)
         self.changelog = []
@@ -102,12 +103,11 @@ class Snap(s_base.Base):
         return meta
 
     @contextlib.contextmanager
-    def getStormRuntime(self, opts=None, user=None):
+    def getStormRuntime(self, query, opts=None, user=None):
         if user is None:
             user = self.user
 
-        runt = s_storm.Runtime(self, opts=opts, user=user)
-        runt.isModuleRunt = True
+        runt = s_storm.Runtime(query, self, opts=opts, user=user)
 
         yield runt
 
@@ -146,8 +146,8 @@ class Snap(s_base.Base):
         mode = opts.get('mode', 'storm')
 
         query = self.core.getStormQuery(text, mode=mode)
-        with self.getStormRuntime(opts=opts, user=user) as runt:
-            async for x in runt.iterStormQuery(query):
+        with self.getStormRuntime(query, opts=opts, user=user) as runt:
+            async for x in runt.execute():
                 yield x
 
     @s_coro.genrhelp
@@ -165,8 +165,8 @@ class Snap(s_base.Base):
 
         # maintained for backward compatibility
         query = self.core.getStormQuery(text, mode=mode)
-        with self.getStormRuntime(opts=opts, user=user) as runt:
-            async for node, path in runt.iterStormQuery(query):
+        with self.getStormRuntime(query, opts=opts, user=user) as runt:
+            async for node, path in runt.execute():
                 yield node
 
     async def nodes(self, text, opts=None, user=None):
@@ -185,6 +185,12 @@ class Snap(s_base.Base):
             logger.warning(mesg)
         await self.fire('warn', mesg=mesg, **info)
 
+    async def warnonce(self, mesg, log=True, **info):
+        if mesg in self._warnonce_keys:
+            return
+        self._warnonce_keys.add(mesg)
+        await self.warn(mesg, log, **info)
+
     async def getNodeByBuid(self, buid):
         '''
         Retrieve a node tuple by binary id.
@@ -250,7 +256,6 @@ class Snap(s_base.Base):
             return node
 
         ndef = None
-
         tags = {}
         props = {}
         nodedata = {}
@@ -269,36 +274,37 @@ class Snap(s_base.Base):
             if sode is None:
                 sode = await layr.getStorNode(buid)
 
-            info = sode[1]
-
-            storndef = info.get('ndef')
-            if storndef is not None:
-                ndef = storndef
+            form = sode.get('form')
+            valt = sode.get('valu')
+            if valt is not None:
+                ndef = (form, valt[0])
                 bylayer['ndef'] = layr
 
-            storprops = info.get('props')
+            storprops = sode.get('props')
             if storprops is not None:
-                props.update(storprops)
-                bylayer['props'].update({p: layr for p in storprops.keys()})
+                for prop, (valu, stype) in storprops.items():
+                    props[prop] = valu
+                    bylayer['props'][prop] = layr
 
-            stortags = info.get('tags')
+            stortags = sode.get('tags')
             if stortags is not None:
                 tags.update(stortags)
                 bylayer['tags'].update({p: layr for p in stortags.keys()})
 
-            stortagprops = info.get('tagprops')
+            stortagprops = sode.get('tagprops')
             if stortagprops is not None:
-                tagprops.update(stortagprops)
-                bylayer['tagprops'].update({p: layr for p in stortagprops.keys()})
+                for tagprop, (valu, stype) in stortagprops.items():
+                    tagprops[tagprop] = valu
+                    bylayer['tagprops'][tagprop] = layr
 
-            stordata = info.get('nodedata')
+            stordata = sode.get('nodedata')
             if stordata is not None:
                 nodedata.update(stordata)
 
         if ndef is None:
             return None
 
-        fullnode = (buid, {
+        pode = (buid, {
             'ndef': ndef,
             'tags': tags,
             'props': props,
@@ -306,7 +312,7 @@ class Snap(s_base.Base):
             'tagprops': tagprops,
         })
 
-        node = s_node.Node(self, fullnode, bylayer=bylayer)
+        node = s_node.Node(self, pode, bylayer=bylayer)
         self.livenodes[buid] = node
         self.buidcache.append(node)
 
@@ -316,9 +322,9 @@ class Snap(s_base.Base):
 
     async def _joinStorGenr(self, layr, genr):
         cache = {}
-        async for sode in genr:
+        async for buid, sode in genr:
             cache[layr.iden] = sode
-            node = await self._joinStorNode(sode[0], cache)
+            node = await self._joinStorNode(buid, cache)
             if node is not None:
                 yield node
 
@@ -361,6 +367,7 @@ class Snap(s_base.Base):
             for layr in self.layers:
                 genr = layr.liftByProp(None, prop.name)
                 async for node in self._joinStorGenr(layr, genr):
+                    # TODO should these type of filters yield?
                     if node.bylayer['props'].get(prop.name) != layr:
                         continue
                     yield node
@@ -616,7 +623,7 @@ class Snap(s_base.Base):
         meta = await self.getSnapMeta()
 
         todo = s_common.todo('storNodeEdits', edits, meta)
-        sodes = await self.core.dyncall(self.wlyr.iden, todo)
+        results = await self.core.dyncall(self.wlyr.iden, todo)
 
         wlyr = self.wlyr
         nodes = []
@@ -627,11 +634,11 @@ class Snap(s_base.Base):
         # and collect up all the callbacks to fire at once at the end.  It is
         # critical to fire all callbacks after applying all Node() changes.
 
-        for sode in sodes:
+        for buid, sode, postedits in results:
 
             cache = {wlyr.iden: sode}
 
-            node = await self._joinStorNode(sode[0], cache)
+            node = await self._joinStorNode(buid, cache)
 
             if node is None:
                 # We got part of a node but no ndef
@@ -639,10 +646,8 @@ class Snap(s_base.Base):
 
             nodes.append(node)
 
-            postedits = sode[1].get('edits', ())
-
             if postedits:
-                actualedits.append((sode[0], sode[1]['form'], postedits))
+                actualedits.append((buid, node.form.name, postedits))
 
             for edit in postedits:
 
@@ -776,7 +781,7 @@ class Snap(s_base.Base):
 
             adds = await self.getNodeAdds(form, valu, props=props)
 
-        except asyncio.CancelledError: # pragma: no cover
+        except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
             raise
 
         except Exception as e:
@@ -786,6 +791,7 @@ class Snap(s_base.Base):
             raise
 
         nodes = await self.applyNodeEdits(adds)
+        assert len(nodes) >= 1
 
         # Adds is top-down, so the first node is what we want
         return nodes[0]
@@ -806,7 +812,7 @@ class Snap(s_base.Base):
         if func is None:
             raise s_exc.NoSuchName(name=name)
 
-        logger.info(f'adding feed nodes ({name}): {len(items)}')
+        logger.info(f'User ({self.user.name}) adding feed data ({name}): {len(items)}')
 
         genr = func(self, items)
         if not isinstance(genr, types.AsyncGeneratorType):
@@ -824,7 +830,7 @@ class Snap(s_base.Base):
         if func is None:
             raise s_exc.NoSuchName(name=name)
 
-        logger.info(f'adding feed data ({name}): {len(items)}')
+        logger.info(f'User ({self.user.name}) adding feed data ({name}): {len(items)}')
 
         retn = func(self, items)
 
@@ -904,6 +910,9 @@ class Snap(s_base.Base):
                             for n2iden, edgeinfo in edges:
                                 await node.addEdge(edgeinfo.get('verb'), n2iden)
 
+                except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
+                    raise
+
                 except Exception as e:
                     if not oldstrict:
                         await self.warn(f'addNodes failed on {formname}, {formvalu}, {forminfo}: {e}')
@@ -915,7 +924,7 @@ class Snap(s_base.Base):
 
                 yield node
 
-            except asyncio.CancelledError:  # pragma: no cover
+            except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
                 raise
 
             except Exception:
