@@ -1,10 +1,9 @@
 import synapse.exc as s_exc
 import synapse.common as s_common
+import synapse.cortex as s_cortex
 import synapse.telepath as s_telepath
 
 import synapse.servers.cell as s_s_univ
-import synapse.servers.cortex as s_s_cortex
-import synapse.servers.cryotank as s_s_cryo
 
 import synapse.tests.utils as s_t_utils
 
@@ -12,19 +11,21 @@ class UnivServerTest(s_t_utils.SynTest):
 
     async def test_server(self):
 
-        with self.getTestDir() as dirn:
+        with self.getTestDir() as dirn, self.withSetLoggingMock() as mock:
 
             outp = self.getTestOutp()
             guid = s_common.guid()
 
-            argv = ['--telepath', 'tcp://127.0.0.1:0/',
-                    '--https', '0',
-                    '--name', 'univtest',
-                    ]
-            argu = list(argv)
-            argu.extend(['synapse.cortex.Cortex', dirn])
+            argv = [
+                'synapse.cortex.Cortex',
+                '--telepath', 'tcp://127.0.0.1:0/',
+                '--https', '0',
+                '--name', 'univtest',
+                dirn,
+            ]
+
             # Start a cortex with the universal loader
-            async with await s_s_univ.main(argu, outp=outp) as core:
+            async with await s_s_univ.main(argv, outp=outp) as core:
 
                 async with await s_telepath.openurl(f'cell://{dirn}') as proxy:
                     podes = await s_t_utils.alist(proxy.eval(f'[ou:org={guid}]'))
@@ -34,37 +35,51 @@ class UnivServerTest(s_t_utils.SynTest):
                 self.true(core.dmon.shared.get('univtest') is core)
 
             # And data persists... and can be seen with the regular synapse cortex server
-            argu = list(argv)
-            argu.append(dirn)
-            async with await s_s_cortex.main(argu, outp=outp) as core:
+            argv = [
+                '--telepath', 'tcp://127.0.0.1:0/',
+                '--https', '0',
+                '--name', 'univtest',
+                dirn,
+            ]
+            async with await s_cortex.Cortex.initFromArgv(argv, outp=outp) as core:
                 async with await s_telepath.openurl(f'cell://{dirn}') as proxy:
                     podes = await s_t_utils.alist(proxy.eval(f'ou:org={guid}'))
                     self.len(1, podes)
 
-            argu = list(argv)
-            argu.extend(['synapse.lib.cell.Cell', dirn])
+            argv = [
+                'synapse.lib.cell.Cell',
+                '--telepath', 'tcp://127.0.0.1:0/',
+                '--https', '0',
+                '--name', 'univtest',
+                dirn,
+            ]
+
             # Start a cortex as a regular Cell
-            async with await s_s_univ.main(argu, outp=outp) as cell:
+            async with await s_s_univ.main(argv, outp=outp) as cell:
                 async with await s_telepath.openurl(f'cell://{dirn}') as proxy:
                     self.eq('cell', await proxy.getCellType())
 
-            argu = list(argv)
-            argu.extend(['synapse.tests.test_lib_cell.EchoAuth', dirn])
+            argv = [
+                'synapse.tests.test_lib_cell.EchoAuth',
+                '--telepath', 'tcp://127.0.0.1:0/',
+                '--https', '0',
+                '--name', 'univtest',
+                dirn,
+            ]
             # Or start the Cortex off a a EchoAuth (don't do this in practice...)
-            async with await s_s_univ.main(argu, outp=outp) as cell:
+            async with await s_s_univ.main(argv, outp=outp) as cell:
                 async with await s_telepath.openurl(f'cell://{dirn}') as proxy:
                     self.eq('echoauth', await proxy.getCellType())
 
-            argu = list(argv)
-            argu.extend(['synapse.lib.newp.Newp', dirn])
+            argv = ['synapse.lib.newp.Newp']
             with self.raises(s_exc.NoSuchCtor):
-                async with await s_s_univ.main(argu, outp=outp) as core:
+                async with await s_s_univ.main(argv, outp=outp) as core:
                     pass
 
-            argu = ['synapse.lib.cell.Cell', dirn,
+            argv = ['synapse.lib.cell.Cell', dirn,
                     '--telepath', 'tcp://127.0.0.1:9999999/',
                     '--https', '0',
                     '--name', 'telecore']
             # Coverage test, for a bad configuration
             with self.raises(OverflowError):
-                obj = await s_s_univ.main(argu, outp=outp)
+                await s_s_univ.main(argv, outp=outp)
